<?php
/**
 * Définit les autorisations du plugin Incarner
 *
 * @plugin     Incarner
 * @copyright  2013
 * @author     Michel Bystranowski
 * @licence    GNU/GPL
 * @package    SPIP\Incarner\Autorisations
 */

/**
 * Fonction d'appel pour le pipeline
 * @pipeline autoriser */
function incarner_autoriser() {
}

/**
 * Autorisation d'incarner
 *
 * On n'est autorisé à changer d'utilisateur que si l'on est webmestre, ou qu'on a un cookie connu.
 *
 * @note
 * Lors de l'appel à l'autorisation, indiquer l'id de l'auteur incarné même si l'info n'est pas utilisée :
 * Ex. : `autoriser('incarner', 'auteur', $id_auteur)`
 * Pour surcharger, il est possible de créer soit une autorisation autoriser_auteur_incarner(), soit autoriser_incarner()
 *
 * @param $faire
 *     Action demandée
 * @param $type
 *     Type d'objet sur lequel appliquer l'action (auteur)
 * @param $id
 *     Identifiant de l'objet (id_auteur)
 * @param $qui
 *     Description de l'auteur demandant l'autorisation
 * @param $opt
 *     Options de cette autorisation
 * @return bool
 *     true s'il a le droit, false sinon
 */
function autoriser_incarner_dist($faire, $type, $id, $qui, $opt) {

	include_spip('incarner_fonctions');

	if (autoriser('webmestre')
			or (isset($_COOKIE['spip_cle_incarner'])
					and incarner_cle_valide($_COOKIE['spip_cle_incarner']))) {
		return true;
	} else {
		return false;
	}
}

/* Le cookie d'incarnation donne droit aux fonctions de debug */
function autoriser_debug($faire, $type, $id, $qui, $opt) {

	return autoriser('incarner');
}
